import _toConsumableArray from "@babel/runtime/helpers/esm/toConsumableArray";
import "../../../src/scss/checklist.scss";
import Vue from 'vue';
export default Vue.extend().extend({
  name: 'w-checklist',
  props: {
    max: {
      type: Number,
      validator: function validator(val) {
        return val >= 0;
      }
    },
    title: String,
    align: {
      type: String,
      default: 'left',
      validator: function validator(val) {
        return val === 'left' || val === 'right';
      }
    },
    checkedColor: {
      type: String,
      default: '#09bb07'
    },
    options: {
      type: Array,
      required: true
    },
    labelKey: {
      type: String,
      default: 'label'
    },
    valueKey: {
      type: String,
      default: 'value'
    },
    value: {
      type: Array,
      default: function _default() {
        return [];
      }
    }
  },
  data: function data() {
    return {
      currentValue: this.value
    };
  },
  watch: {
    value: function value(val) {
      this.currentValue = val;
      this.$emit('change', val);
    },
    currentValue: function currentValue(val) {
      if (this.max && val.length > this.max) {
        val = val.slice(0, this.max);
      }

      this.$emit('input', val);
    }
  },
  methods: {
    onClick: function onClick(option) {
      if (option.disabled) {
        return;
      }

      var value = typeof option === 'string' ? option : option[this.valueKey];

      if (this.currentValue.includes(value)) {
        this.currentValue = this.currentValue.filter(function (val) {
          return val !== value;
        });
      } else {
        // DO NOT use push()
        this.currentValue = [].concat(_toConsumableArray(this.currentValue), [value]);
      }
    },
    isChecked: function isChecked(option) {
      var value = typeof option === 'string' ? option : option[this.valueKey];
      return this.currentValue.includes(value);
    }
  },
  render: function render() {
    var _this = this;

    var h = arguments[0];
    return h("div", [this.title && h("div", {
      "class": "weui-cells__title",
      "domProps": {
        "innerHTML": this.title
      }
    }), h("div", {
      "class": "weui-cells weui-cells_checkbox"
    }, [this.options.map(function (option) {
      return h("label", {
        "key": option.label || option,
        "class": {
          'weui-cell': true,
          'weui-check__label': true,
          'weui-check__label-disabled': option.disabled
        },
        "on": {
          "click": function click() {
            _this.onClick(option);
          }
        }
      }, [_this.align === 'left' && h("div", {
        "class": "weui-cell__hd"
      }, [h("i", {
        "style": {
          color: _this.checkedColor
        },
        "class": {
          'weui-icon-checked': true,
          checked: _this.isChecked(option)
        }
      })]), h("div", {
        "class": "weui-cell__bd"
      }, [h("p", {
        "domProps": {
          "textContent": option[_this.labelKey] || option
        }
      })]), _this.align === 'right' && h("div", {
        "class": "weui-cell__hd"
      }, [h("i", {
        "style": {
          color: _this.checkedColor
        },
        "class": {
          'weui-icon-checked': true,
          checked: _this.isChecked(option)
        }
      })])]);
    })])]);
  }
});
//# sourceMappingURL=WChecklist.js.map